#include "duck.h"

/****************
* Canard vivant *
****************/

void initDuckAlive(duck &d, float speed)
{
	d.x= random(SCREEN_WIDTH-DUCK_SIZE);
	d.y= random(BOTTOM_SHOOTING_RANGE-DUCK_SIZE);
	d.RECT.w= d.w= DUCK_SIZE;
	d.RECT.h= d.h= DUCK_SIZE;

	d.color= random(3);
	d.horizontal= 3;
	d.vertical= 0;

	d.wing= 0;
	d.wingChange= DUCK_SIZE;

    d.cptRandom= 0;
    d.limitCptRandom= random(RANDOM_LIMIT);

	d.hit= false;
	d.falling= false;
	d.escape= false;
	d.noDisplay= false;

	d.RECT.w= DUCK_SIZE;
	d.RECT.h= DUCK_SIZE;

    switch (d.color)
	{
		case 0:
			d.mvt_x= speed*SPEED_BLACK;
			d.mvt_y= speed*SPEED_BLACK;
			break;

		case 1:
			d.mvt_x= speed*SPEED_RED;
			d.mvt_y= speed*SPEED_RED;
			break;

		case 2:
			d.mvt_x= speed*SPEED_BLUE;
			d.mvt_y= speed*SPEED_BLUE;
			break;

		default:
            d.color= 0;
			d.mvt_x= speed*SPEED_BLACK;
			d.mvt_y= speed*SPEED_BLACK;
			break;
	}
}

void operationDuckAlive(duck &d, SDL_Surface *screen, surfaces SUR)
{
//Aléatoire
    d.cptRandom++;

    if(d.cptRandom> d.limitCptRandom)
    {
        do
        {
            d.tmpRandom= random(3)-1;
        } while (d.tmpRandom==0);

        d.mvt_x*= d.tmpRandom;

        do
        {
            d.tmpRandom= random(3)-1;
        } while (d.tmpRandom==0);

        d.mvt_y*= d.tmpRandom;

        d.cptRandom=0;
        d.limitCptRandom= random(RANDOM_LIMIT);
    }

//Déplacement
    d.x+=d.mvt_x; //Horizontale
    if (d.x<=0 || d.x >= SCREEN_WIDTH-DUCK_SIZE)
    {
        d.x-=d.mvt_x;
        d.mvt_x*=-1;
    }

    d.y+=d.mvt_y; //Verticale
    if (d.y<=0 || d.y>= BOTTOM_SHOOTING_RANGE-DUCK_SIZE)
    {
        d.y-=d.mvt_y;
        d.mvt_y*=-1;
    }

//Ailes
    d.wing+=d.wingChange;

    if (d.wing<0 || d.wing>(2*DUCK_SIZE))
    {
        d.wing-=d.wingChange;
        d.wingChange*=-1;
    }

//Orientation horizontale
    if (d.mvt_x<0)
        d.horizontal= 0;
    if (d.mvt_x>0)
        d.horizontal= 3;

//Orientation verticale
    if (d.mvt_y<0)
        d.vertical= 0;
    if (d.mvt_y>0)
        d.vertical= 3*DUCK_SIZE;

//Affichage
    d.RECT.x= d.horizontal*DUCK_SIZE+d.wing;
    d.RECT.y= d.vertical+d.color*DUCK_SIZE;

    applySurface(d.x, d.y, SUR.duck, screen, &d.RECT);
}

/**************
* Canard mort *
**************/

void initDuckDead(duck &d)
{
	d.RECT.x= 0;
	d.RECT.y= d.color*DUCK_SIZE+6*DUCK_SIZE;

    d.mvt_y= SPEED_FALLING;

	d.hit= true;
	d.cpt= 0;

	d.RECTPoints.w= 29;
	d.RECTPoints.h= 16;
	d.RECTPoints.x= 0;
	d.RECTPoints.y= d.color*d.RECTPoints.h;

//Affichage des points
	if(d.x+DUCK_SIZE+d.RECTPoints.w > SCREEN_WIDTH) //S'il n'y a pas de la place à droite du canard
        d.points_x= d.x-d.RECTPoints.w; //On affiche les points gagnés à gauche du canard
    else //S'il y a de la place à droite du canard
        d.points_x= d.x+DUCK_SIZE; //On affiche les points gagnés à droite du canard

    d.orientationFall= 1;
}

void operationDuckDead(duck &d, SDL_Surface *screen, surfaces SUR)
{
//Déplacement
    if(!d.falling) //"Stand-by"
    {
        d.cpt++;
        applySurface(d.points_x, d.y, SUR.points, screen, &d.RECTPoints); //Affiche les points remportés
        if(d.cpt>10)
        {
            d.falling= true;
            d.RECT.x+= DUCK_SIZE;
        }
    }
    else //Chute
    {
        d.y+=d.mvt_y;
        d.orientationFall*=-1;

        if(d.y>BOTTOM_SHOOTING_RANGE)
            d.noDisplay= true;
    }

//Affichage
    if(d.falling)
        d.RECT.x+= d.orientationFall*DUCK_SIZE;
    applySurface(d.x, d.y, SUR.duck, screen, &d.RECT);
}

/*********************
* Canard s'échappant *
*********************/

void initEscapeDuck(duck &d)
{
	if (!d.hit)
	{
        d.escape= true;
        d.mvt_y=-SPEED_FALLING;
        d.mvt_x=0;
	}
}

void operationEscapeDuck(duck &d, SDL_Surface *screen, surfaces SUR)
{
//Déplacement
    d.y+=d.mvt_y;
	if (d.y+DUCK_SIZE <0)
		d.noDisplay = true;

//Ailes
    d.wing+=d.wingChange;
    if (d.wing<0 || d.wing>(2*DUCK_SIZE))
    {
        d.wing-=d.wingChange;
        d.wingChange*=-1;
    }

//Affichage
    d.RECT.x= d.horizontal*DUCK_SIZE+d.wing;
    d.RECT.y= d.color*DUCK_SIZE;
    applySurface(d.x, d.y, SUR.duck, screen, &d.RECT);
}

/********************
* Gestion du canard *
********************/

void operationDuck(duck &d, SDL_Surface *screen, surfaces SUR)
{
    if(!d.noDisplay)
    {
        if(!d.hit && !d.escape)
            operationDuckAlive(d, screen, SUR);

        else if (d.hit)
            operationDuckDead(d, screen, SUR);

        else if (d.escape)
            operationEscapeDuck(d, screen, SUR);
    }
}

bool shoot(duck d, int m_x, int m_y)
{
	int leftT, rightT, topT, bottomT;

	leftT = d.x;
	rightT = d.x + d.w;
	topT = d.y;
	bottomT = d.y + d.h;

	if(bottomT < m_y || topT > m_y || leftT > m_x || rightT < m_x )
    	return false;

	return true;
}
