#ifndef GENERAL_H_INCLUDED
#define GENERAL_H_INCLUDED

#include <SDL/SDL.h>
#include <SDL/SDL_image.h>
#include <SDL/SDL_ttf.h>

#include <string>
#include <fstream>
#include <iostream>

using namespace std;

struct surfaces
{
    SDL_Surface *backgroundMenu;
    SDL_Surface *backgroundGame;
	SDL_Surface *backgroundGameBlit;
	SDL_Surface *duck;
	SDL_Surface *points;
	SDL_Surface *dog;
	SDL_Surface *loader;
	SDL_Surface *results;
	SDL_Surface *target;
	SDL_Surface *message;
	SDL_Surface *pause;
};

const int SCREEN_WIDTH = 750;
const int SCREEN_HEIGHT = 761;
const int SCREEN_COLOR = 32;
const int BOTTOM_SHOOTING_RANGE = 450;

/******************** Nom de la fonction ********************
* initSurfaces                                              *
*********************** Auteur  Dates ***********************
* Guillaume Gamelas *** 05/12/2012                          *
************************ Description ************************
* Initialse les SDL_Surface                                 *
************************** Entres **************************
* Images et sprites                                         *
************************** Sorties **************************
*                                                           *
************************************************************/
void initSurfaces(surfaces &SUR);

/******************** Nom de la fonction ********************
* closeSurfaces                                             *
*********************** Auteur  Dates ***********************
* Guillaume Gamelas *** 05/12/2012                          *
************************ Description ************************
* Libre les SDL_Surface                                    *
************************** Entres **************************
* Images et sprites                                         *
************************** Sorties **************************
*                                                           *
************************************************************/
void closeSurfaces(surfaces &SUR);

/******************** Nom de la fonction ********************
* initPositionRect                                          *
*********************** Auteur  Dates ***********************
* Guillaume Gamelas *** 25/11/2012                          *
************************ Description ************************
* Intgre des coordonnes dans un SDL_Rect                  *
************************** Entres **************************
* Structure de positions                                    *
* Ordonne                                                  *
* Abscisse                                                  *
************************** Sorties **************************
*                                                           *
************************************************************/
void initPositionRect(SDL_Rect &pos, int x, int y);

/******************** Nom de la fonction ********************
* loadImageWithColorKey                                     *
*********************** Auteur  Dates ***********************
* Guillaume Gamelas *** 24/11/2012                          *
************************ Description ************************
* Rend transparent une couleur d'une image                  *
************************** Entres **************************
* Nom (et chemin) de l'image                                *
* Taux de rouge                                             *
* Taux de vert                                              *
* Taux de bleu                                              *
************************** Sorties **************************
* Image entre en paramtre, sans la couleur                *
************************************************************/
SDL_Surface *loadImageWithColorKey(string filename, int r, int g, int b);

/******************** Nom de la fonction ********************
* applySurface                                              *
*********************** Auteur  Dates ***********************
* Guillaume Gamelas *** 22/11/2012                          *
************************ Description ************************
* Blit des Surfaces venues de la feuille de sprite          *
************************** Entres **************************
* Ordonne de l'image  blitter                             *
* Abscisse de l'image  blitter                             *
* Surface  blitter                                         *
* Support de l'image                                        *
* Partie de la surface  blitter => Image                   *
************************** Sorties **************************
*                                                           *
************************************************************/
void applySurface(int x, int y, SDL_Surface *source, SDL_Surface *destination, SDL_Rect *clip= NULL);

/******************** Nom de la fonction ********************
* showMessageScreen                                         *
*********************** Auteur  Dates ***********************
* Guillaume Gamelas *** 27/11/2012                          *
************************ Description ************************
* Blitte le texte contenu dans une variable                 *
************************** Entres **************************
* Texte  blitter                                           *
* Ordonne du texte  blitter                               *
* Abscisse du texte  blitter                               *
* Police d'criture                                         *
* Taille de police                                          *
* Couleur de police                                         *
* Fentre                                                   *
************************** Sorties **************************
*                                                           *
************************************************************/
void showMessageScreen(string message,int x ,int y, TTF_Font *font,
                       int fontSize, SDL_Color textColor, SDL_Surface *screen, surfaces SUR);

/******************** Nom de la fonction ********************
* random                                                    *
*********************** Auteur  Dates ***********************
* Tho Chassaigne *** 30/11/2012                            *
************************ Description ************************
* Gnre un nombre alatoire                                *
************************** Entres **************************
* Nombre maximum : max                                      *
************************** Sorties **************************
* Nombre alatoire compris entre 0 et max non-inclu         *
************************************************************/
int random(int max);

/******************** Nom de la fonction ********************
* error                                                     *
*********************** Auteur  Dates ***********************
* Guillaume Gamelas *** 12/12/2012                          *
************************ Description ************************
* Ecrit la dernire erreur dans un fichier "Error.txt"      *
* Arrte le programme                                       *
************************** Entres **************************
*                                                           *
************************** Sorties **************************
*                                                           *
************************************************************/
void error();

#endif // GENERAL_H_INCLUDED
